@@ -140,7 +140,8 @@ class TestConfigs:
             cfg.default_value = module.Nested()
             assert cfg.default_value == module.Nested()
 
-        conf1 = OmegaConf.structured(module.NestedConfig)
+        with pytest.warns(UserWarning):
+            conf1 = OmegaConf.structured(module.NestedConfig)
         validate(conf1)
         conf1 = OmegaConf.structured(module.NestedConfig(default_value=module.Nested()))
         validate(conf1)
@@ -183,7 +184,8 @@ class TestConfigs:
 
     def test_assignment_to_nested_structured_config(self, class_type: str) -> None:
         module: Any = import_module(class_type)
-        conf = OmegaConf.structured(module.NestedConfig)
+        with pytest.warns(UserWarning):
+            conf = OmegaConf.structured(module.NestedConfig)
         with pytest.raises(ValidationError):
             conf.default_value = 10
 
@@ -942,3 +944,36 @@ class TestDictSubclass:
             "as_none": {"x": 100},
             "not_optional": {"a": 10},
         }
+
+    @pytest.mark.parametrize(  # type: ignore
+        "update_value,expected",
+        [
+            pytest.param([], {"list": []}, id="empty"),
+            pytest.param(
+                [{"name": "Bond"}],
+                {"list": [{"name": "Bond", "age": "???"}]},
+                id="partial",
+            ),
+            pytest.param(
+                [{"name": "Bond", "age": 7}],
+                {"list": [{"name": "Bond", "age": 7}]},
+                id="complete",
+            ),
+            pytest.param(
+                [{"age": "double o seven"}],
+                pytest.raises(ValidationError),
+                id="complete",
+            ),
+        ],
+    )
+    def test_update_userlist(
+        self, class_type: str, update_value: Any, expected: Any
+    ) -> None:
+        module: Any = import_module(class_type)
+        cfg = OmegaConf.structured(module.UserList)
+        if isinstance(expected, dict):
+            OmegaConf.update(cfg, "list", update_value, merge=True)
+            assert cfg == expected
+        else:
+            with pytest.raises(ValidationError):
+                OmegaConf.update(cfg, "list", update_value, merge=True)
